@@ -10,32 +10,30 @@
 import os
 import stat
 import tempfile
+from io import BytesIO, StringIO
 from shutil import copy
 
-from io import StringIO
-from io import BytesIO
-
 # Package imports.
 from .app import App
+from .comments import Comments
 from .contenttypes import ContentTypes
 from .core import Core
 from .custom import Custom
+from .exceptions import EmptyChartSeries
 from .metadata import Metadata
 from .relationships import Relationships
-from .sharedstrings import SharedStrings
 from .rich_value import RichValue
-from .rich_value_types import RichValueTypes
 from .rich_value_rel import RichValueRel
 from .rich_value_structure import RichValueStructure
+from .rich_value_types import RichValueTypes
+from .sharedstrings import SharedStrings
 from .styles import Styles
+from .table import Table
 from .theme import Theme
 from .vml import Vml
-from .table import Table
-from .comments import Comments
-from .exceptions import EmptyChartSeries
 
 
-class Packager(object):
+class Packager:
     """
     A class for writing the Excel XLSX Packager file.
 
@@ -89,7 +87,7 @@ class Packager(object):
 
         """
 
-        super(Packager, self).__init__()
+        super().__init__()
 
         self.tmpdir = ""
         self.in_memory = False
@@ -225,8 +223,8 @@ class Packager(object):
             # Check that the chart has at least one data series.
             if not chart.series:
                 raise EmptyChartSeries(
-                    "Chart%d must contain at least one "
-                    "data series. See chart.add_series()." % index
+                    f"Chart{index} must contain at least one "
+                    f"data series. See chart.add_series()."
                 )
 
             chart._set_xml_writer(
@@ -416,7 +414,7 @@ class Packager(object):
         properties = self.workbook.custom_properties
         custom = Custom()
 
-        if not len(properties):
+        if not properties:
             return
 
         custom._set_properties(properties)
@@ -736,6 +734,7 @@ class Packager(object):
         rels._assemble_xml_file()
 
     def _add_image_files(self):
+        # pylint: disable=consider-using-with
         # Write the /xl/media/image?.xml files.
         workbook = self.workbook
         index = 1
@@ -784,6 +783,7 @@ class Packager(object):
             index += 1
 
     def _add_vba_project_signature(self):
+        # pylint: disable=consider-using-with
         # Copy in a vbaProjectSignature.bin file.
         vba_project_signature = self.workbook.vba_project_signature
         vba_project_signature_is_stream = self.workbook.vba_project_signature_is_stream
@@ -819,6 +819,7 @@ class Packager(object):
             self.filenames.append((os_filename, xml_vba_signature_name, True))
 
     def _add_vba_project(self):
+        # pylint: disable=consider-using-with
         # Copy in a vbaProject.bin file.
         vba_project = self.workbook.vba_project
         vba_project_is_stream = self.workbook.vba_project_is_stream
